@@ -21,9 +21,7 @@ DIST="$ROOT/.perl-layer/dist"
 set -uex
 
 # sanity check of required tools
-command -v perlstrip # cpanm --notest Perl::Strip
 command -v parallel # GNU parallel
-command -v timeout # coreutils
 
 # clean up
 rm -rf "$OPT-$PLATFORM"
@@ -46,7 +44,7 @@ docker run \
     "public.ecr.aws/shogo82148/lambda-provided:build-al2-$PLATFORM" \
     ./author/build-paws-al2.sh "$TAG"
 
-find "$OPT-$PLATFORM" -type f -a -name '*.pm' -print0 | parallel -0 "$ROOT/author/perlstrip.sh"
+find "$OPT-$PLATFORM" -type f -a -name '*.pm' -print0 | parallel -0 -j 32 "$ROOT/author/perlstrip.sh"
 
 cd "$OPT-$PLATFORM"
 mkdir -p "$DIST"
