@@ -16,9 +16,7 @@ DIST="$ROOT/.perl-layer/dist"
 set -uex
 
 # sanity check of required tools
-command -v perlstrip # cpanm --notest Perl::Strip
 command -v parallel # GNU parallel
-command -v timeout # coreutils
 
 # clean up
 rm -rf "$OPT"
@@ -32,7 +30,7 @@ docker run --rm \
     public.ecr.aws/shogo82148/lambda-provided:build-alami \
     ./author/build-paws.sh "$TAG"
 
-find "$OPT" -type f -a -name '*.pm' -print0 | parallel -0 "$ROOT/author/perlstrip.sh"
+find "$OPT" -type f -a -name '*.pm' -print0 | parallel -0 -j 32 "$ROOT/author/perlstrip.sh"
 
 cd "$OPT"
 mkdir -p "$DIST"
